Documentation
=============

```
  Usage:
        gpu --json [--pretty]
        gpu --xml
        gpu --yaml
        gpu processes
        gpu system
        gpu status
        gpu

  This command returns some information about NVIDIA GPUs if your 
  system has them.

  Options:
      --json   returns the information in json
      --xml    returns the information in xml
      --yaml   returns the information in xml
```

.
